@@ -8,14 +8,16 @@ import (
 	"github.com/jdkato/prose/internal/util"
 )
 
-func BenchmarkEasyWordsLookup(b *testing.B) {
+func BenchmarkEasyWordsLookupMap(b *testing.B) {
 	cases := util.ReadDataFile(filepath.Join(testdata, "syllables.json"))
 	tests := make(map[string]int)
 	util.CheckError(json.Unmarshal(cases, &tests))
 
 	for n := 0; n < b.N; n++ {
 		for word := range tests {
-			util.StringInSlice(word, easyWords)
+			if _, ok := easyWords[word]; ok {
+
+			}
 		}
 	}
 }
